@@ -4,7 +4,8 @@
   version <- read.dcf(file=system.file("DESCRIPTION", package=pkgname),
                       fields="Version")
   packageStartupMessage("This is ",paste(pkgname, version))
-  packageStartupMessage(pkgname, " is BETA software! Please report any bugs.")
+  # packageStartupMessage(pkgname, " is BETA software! Please report any bugs.")
+  packageStartupMessage("For questions and issues, please see github.com/SachaEpskamp/bootnet.")
 }
 
 # Please do not look further down this script.
